Credits
-------

The lead developers of the TOM Toolkit are `William Lindstrom <https://lco.global/people/>`_
and `Joey Chatelain <https://sites.google.com/site/josephchatelain>`_,
professional software developers with the Las Cumbres Observatory software team,
together with `Jon Nation <https://lco.global/people/>`_, `Curtis McCully <https://lco.global/people/>`_,
`Matt Daily <https://lco.global/people/>`_ and `Mark Bowman <https://lco.global/people/>`_.  `Rachel Street <https://lco.global/user/rstreet/>`_ is the project's Principle Investigator.
The TOM Toolkit is grateful for the advice and collaboration with `Andy Howell <http://www.dahowell.com/>`_,
`Edward Gomez <https://www.zemogle.net/>`_, Craig Pellegrino, Jamie Burke and the rest of the LCO Science team.
The `original Toolkit <https://zenodo.org/records/4437764>`_ was developed by
Austin Riba, David Collom and William Lindstrom.

Our team very much welcome input from the community, and we are grateful to
the following people for their many contributions:
 - Dan Avner, NOIRLab
 - Doug Arnold, Liverpool Telescope
 - Etienne Bachelet, IPAC/Caltech
 - Ezequiel Contreras Martinez, UCSB
 - Griffin Hosseinzadeh, University of Arizona
 - Bryan Miller, Gemini Observatory
 - Brendan Mills, UCSB
 - Julien Peloton, Fink
